==> gnome-online-accounts_3.2.1.orig.tar.xz: gnome-online-accounts-3.2.1/src/goabackend/goalogging.h <==
/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
/*
 * Copyright (C) 2011 Red Hat, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Author: David Zeuthen <davidz@redhat.com>
 */

#if !defined (__GOA_BACKEND_INSIDE_GOA_BACKEND_H__) && !defined (GOA_BACKEND_COMPILATION)
#error "Only <goabackend/goabackend.h> can be included directly."
#endif

#ifndef __GOA_LOGGING_H__
#define __GOA_LOGGING_H__

#include <goabackend/goabackendtypes.h>

G_BEGIN_DECLS

void goa_log (GoaLogLevel     level,
              const gchar    *function,
              const gchar    *location,
              const gchar    *format,
              ...) G_GNUC_PRINTF (4, 5);

/**
 * goa_debug:
 * @args: printf()-style format string and arguments
 *
 * Logging macro for %GOA_LOG_LEVEL_DEBUG.
 */
#define goa_debug(args...)   goa_log(GOA_LOG_LEVEL_DEBUG, G_STRFUNC, G_STRLOC, args);

/**
 * goa_info:
 * @args: printf()-style format string and arguments
 *
 * Logging macro for %GOA_LOG_LEVEL_INFO.
 */
#define goa_info(args...)    goa_log(GOA_LOG_LEVEL_INFO, G_STRFUNC, G_STRLOC, args);

/**
 * goa_notice:
 * @args: printf()-style format string and arguments
 *
 * Logging macro for %GOA_LOG_LEVEL_NOTICE.
 */
#define goa_notice(args...)    goa_log(GOA_LOG_LEVEL_NOTICE, G_STRFUNC, G_STRLOC, args);

/**
 * goa_warning:
 * @args: printf()-style format string and arguments
 *
 * Logging macro for %GOA_LOG_LEVEL_WARNING.
 */
#define goa_warning(args...) goa_log(GOA_LOG_LEVEL_WARNING, G_STRFUNC, G_STRLOC, args);

/**
 * goa_error:
 * @args: printf()-style format string and arguments
 *
 * Logging macro for %GOA_LOG_LEVEL_ERROR.
 */
#define goa_error(args...)   goa_log(GOA_LOG_LEVEL_ERROR, G_STRFUNC, G_STRLOC, args);


G_END_DECLS

#endif /* __GOA_LOGGING_H__ */

==> gnome-online-accounts-3.7.3.tar.xz: gnome-online-accounts-3.7.3/src/goabackend/goalogging.h <==
/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
/*
 * Copyright (C) 2011 Red Hat, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Author: David Zeuthen <davidz@redhat.com>
 */

#if !defined (__GOA_BACKEND_INSIDE_GOA_BACKEND_H__) && !defined (GOA_BACKEND_COMPILATION)
#error "Only <goabackend/goabackend.h> can be included directly."
#endif

#ifndef __GOA_LOGGING_H__
#define __GOA_LOGGING_H__

#include <goabackend/goabackendtypes.h>

G_BEGIN_DECLS

void goa_log (GoaLogLevel     level,
              const gchar    *function,
              const gchar    *location,
              const gchar    *format,
              ...) G_GNUC_PRINTF (4, 5);

/**
 * goa_debug:
 * @...: printf()-style format string and arguments
 *
 * Logging macro for %GOA_LOG_LEVEL_DEBUG.
 */
#define goa_debug(...)   goa_log(GOA_LOG_LEVEL_DEBUG, G_STRFUNC, G_STRLOC, __VA_ARGS__);

/**
 * goa_info:
 * @...: printf()-style format string and arguments
 *
 * Logging macro for %GOA_LOG_LEVEL_INFO.
 */
#define goa_info(...)    goa_log(GOA_LOG_LEVEL_INFO, G_STRFUNC, G_STRLOC, __VA_ARGS__);

/**
 * goa_notice:
 * @...: printf()-style format string and arguments
 *
 * Logging macro for %GOA_LOG_LEVEL_NOTICE.
 */
#define goa_notice(...)    goa_log(GOA_LOG_LEVEL_NOTICE, G_STRFUNC, G_STRLOC, __VA_ARGS__);

/**
 * goa_warning:
 * @...: printf()-style format string and arguments
 *
 * Logging macro for %GOA_LOG_LEVEL_WARNING.
 */
#define goa_warning(...) goa_log(GOA_LOG_LEVEL_WARNING, G_STRFUNC, G_STRLOC, __VA_ARGS__);

/**
 * goa_error:
 * @...: printf()-style format string and arguments
 *
 * Logging macro for %GOA_LOG_LEVEL_ERROR.
 */
#define goa_error(...)   goa_log(GOA_LOG_LEVEL_ERROR, G_STRFUNC, G_STRLOC, __VA_ARGS__);


G_END_DECLS

#endif /* __GOA_LOGGING_H__ */
